package com.xy.service.factory.cmd.impl;

import cn.hutool.json.JSONObject;
import com.xy.annotate.Factory;
import com.xy.device.EnumDeviceVersionUpStatus;
import com.xy.device.EnumMqttCmdTempletTask;
import com.xy.dto.ActivityInfoDto;
import com.xy.dto.DeviceVersionUpDto;
import com.xy.dto.MqttDto;
import com.xy.service.ActivityInfoService;
import com.xy.service.DeviceVersionUpServiceImpl;
import com.xy.service.factory.cmd.CmdService;
import com.xy.utils.R;
import com.xy.utils.SysDictUtils;
import lombok.AllArgsConstructor;

import java.util.List;

/**
 * 任务指令 接口实现
 */
@Factory(type = "task")
@AllArgsConstructor
public class TaskCmdServiceImpl implements CmdService {

    private ActivityInfoService activityInfoService;

    private DeviceVersionUpServiceImpl deviceVersionUpService;

    @Override
    public R senCommand(List<MqttDto> mqttDtos) {
        for (MqttDto mqttDto : mqttDtos) {
            JSONObject data = mqttDto.getPater().getData();
            String type = data.getStr("type");
            //终止活动
            if (type.equals(EnumMqttCmdTempletTask.ABORT.getCode())) {
                activityInfoService.abort(new ActivityInfoDto.Abort().setDeviceId(mqttDto.getDeviceId()));
            }
            //版本升级
            if (type.equals(EnumMqttCmdTempletTask.APPUPDATE.getCode())) {
                Integer value = SysDictUtils.getValue(EnumDeviceVersionUpStatus.Code.CODE.getCode(), EnumDeviceVersionUpStatus.N_1.getCode(), Integer.class);
                DeviceVersionUpDto.SaveOrUpdate saveOrUpdate = new DeviceVersionUpDto.SaveOrUpdate()
                        .setDeviceId(mqttDto.getDeviceId())
                        .setDeviceVersion(data.getStr("version"))
                        .setAccumSendNum(1);
                saveOrUpdate.setCmdValue(mqttDto.getPater().getData().toString());
                saveOrUpdate.setStatus(value);
                deviceVersionUpService.saveOrUpdate(saveOrUpdate);
            }
        }
        return R.ok();
    }

    @Override
    public R resultBack(MqttDto.ResultBack resultBack) {
        DeviceVersionUpDto.DeviceVersionUpResultBack deviceVersionUpResultBack = resultBack.getDeviceVersionUpResultBack();
        //版本升级
        if (deviceVersionUpResultBack != null) {
            DeviceVersionUpDto.SaveOrUpdate saveOrUpdate = new DeviceVersionUpDto.SaveOrUpdate()
                    .setDeviceId(deviceVersionUpResultBack.getDeviceId())
                    .setDeviceVersion(deviceVersionUpResultBack.getDeviceVersion());
            saveOrUpdate.setStatus(deviceVersionUpResultBack.getStatus());
            saveOrUpdate.setProgress(deviceVersionUpResultBack.getProgress());
            saveOrUpdate.setMsg(deviceVersionUpResultBack.getMsg());
            deviceVersionUpService.saveOrUpdate(saveOrUpdate);
        }
        return R.ok();
    }
}
